@@ -81,7 +81,7 @@ function loadNearbyFriends() {
 }
 
 function parseFriends(response) {
-    console.log("Response: " + response);
+    //console.log("Response: " + response);
     var data = eval("[" + response + "]")[0].response;
     var count = 0;
     friendsModel.clear();
@@ -197,7 +197,7 @@ function loadVenue(venueID) {
 }
 
 function parseVenue(response) {
-    console.log("VENUE: " + response);
+    //console.log("VENUE: " + response);
     var data = eval("[" + response + "]")[0].response;
     waiting.state = "hidden";
     var venue = data.venue;
